<?php

namespace Litecms\Demorequest\Http\Controllers;

use App\Http\Controllers\AdminApiController as AdminController;
use Litecms\Demorequest\Http\Requests\DemoAdminApiRequest;
use Litecms\Demorequest\Interfaces\DemoRepositoryInterface;
use Litecms\Demorequest\Models\Demo;

/**
 * Admin API controller class.
 */
class DemoAdminApiController extends AdminController
{
    /**
     * Initialize demo controller.
     *
     * @param type DemoRepositoryInterface $demo
     *
     * @return type
     */
    public function __construct(DemoRepositoryInterface $demo)
    {
        $this->repository = $demo;
        parent::__construct();
    }

    /**
     * Display a list of demo.
     *
     * @return json
     */
    public function index(DemoAdminApiRequest $request)
    {
        $demos  = $this->repository
            ->setPresenter('\\Litecms\\Demorequest\\Repositories\\Presenter\\DemoListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $demos['code'] = 2000;
        return response()->json($demos) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display demo.
     *
     * @param Request $request
     * @param Model   Demo
     *
     * @return Json
     */
    public function show(DemoAdminApiRequest $request, Demo $demo)
    {
        $demo         = $demo->presenter();
        $demo['code'] = 2001;
        return response()->json($demo)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new demo.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(DemoAdminApiRequest $request, Demo $demo)
    {
        $demo         = $demo->presenter();
        $demo['code'] = 2002;
        return response()->json($demo)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new demo.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(DemoAdminApiRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $demo          = $this->repository->create($attributes);
            $demo          = $demo->presenter();
            $demo['code']  = 2004;

            return response()->json($demo)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
;
        }
    }

    /**
     * Show demo for editing.
     *
     * @param Request $request
     * @param Model   $demo
     *
     * @return json
     */
    public function edit(DemoAdminApiRequest $request, Demo $demo)
    {
        $demo         = $demo->presenter();
        $demo['code'] = 2003;
        return response()-> json($demo)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the demo.
     *
     * @param Request $request
     * @param Model   $demo
     *
     * @return json
     */
    public function update(DemoAdminApiRequest $request, Demo $demo)
    {
        try {

            $attributes = $request->all();

            $demo->update($attributes);
            $demo         = $demo->presenter();
            $demo['code'] = 2005;

            return response()->json($demo)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the demo.
     *
     * @param Request $request
     * @param Model   $demo
     *
     * @return json
     */
    public function destroy(DemoAdminApiRequest $request, Demo $demo)
    {

        try {

            $t = $demo->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('demorequest::demo.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
