<?php

namespace Litecms\Demorequest\Http\Controllers;

use App\Http\Controllers\PublicApiController as PublicController;
use Litecms\Demorequest\Interfaces\DemoRepositoryInterface;
use Litecms\Demorequest\Repositories\Presenter\DemoItemTransformer;

/**
 * Pubic API controller class.
 */
class DemoPublicApiController extends PublicController
{
    /**
     * Constructor.
     *
     * @param type \Litecms\Demo\Interfaces\DemoRepositoryInterface $demo
     *
     * @return type
     */
    public function __construct(DemoRepositoryInterface $demo)
    {
        $this->repository = $demo;
        parent::__construct();
    }

    /**
     * Show demo's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $demos = $this->repository
            ->setPresenter('\\Litecms\\Demorequest\\Repositories\\Presenter\\DemoListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $demos['code'] = 2000;
        return response()->json($demos)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show demo.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $demo = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($demo)) {
            $demo         = $this->itemPresenter($module, new DemoItemTransformer);
            $demo['code'] = 2001;
            return response()->json($demo)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
