<?php

namespace Litecms\Demorequest\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Litecms\Demorequest\Models\Demo;

class DemoPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the demo.
     *
     * @param User $user
     * @param Demo $demo
     *
     * @return bool
     */
    public function view(User $user, Demo $demo)
    {
        if ($user->canDo('demorequest.demo.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $demo->user_id;
    }

    /**
     * Determine if the given user can create a demo.
     *
     * @param User $user
     * @param Demo $demo
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('demorequest.demo.create');
    }

    /**
     * Determine if the given user can update the given demo.
     *
     * @param User $user
     * @param Demo $demo
     *
     * @return bool
     */
    public function update(User $user, Demo $demo)
    {
        if ($user->canDo('demorequest.demo.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $demo->user_id;
    }

    /**
     * Determine if the given user can delete the given demo.
     *
     * @param User $user
     * @param Demo $demo
     *
     * @return bool
     */
    public function destroy(User $user, Demo $demo)
    {
        if ($user->canDo('demorequest.demo.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $demo->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
