<?php

namespace Litecms\Demorequest\Providers;

use Illuminate\Support\ServiceProvider;

class DemorequestServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'demorequest');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'demorequest');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('demorequest', function ($app) {
            return $this->app->make('Litecms\Demorequest\Demorequest');
        });

        // Bind Demo to repository
        $this->app->bind(
            \Litecms\Demorequest\Interfaces\DemoRepositoryInterface::class,
            \Litecms\Demorequest\Repositories\Eloquent\DemoRepository::class
        );

        $this->app->register(\Litecms\Demorequest\Providers\AuthServiceProvider::class);
        $this->app->register(\Litecms\Demorequest\Providers\EventServiceProvider::class);
        $this->app->register(\Litecms\Demorequest\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['demorequest'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/demorequest.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/demorequest')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/demorequest')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
